@@ -25,13 +25,14 @@
 #define ERRS_H
 /*----------------------------------------------------------------------------*/
 enum {
-    ERR_OK,      /**< Everything OK */
+    ERR_OK,      /**< OK */
     ERR_FILE,    /**< File error (cannot access / bad permissions) */
     ERR_FILE_RW, /**< File read / write error */
     ERR_FILE_CR, /**< File can not be created */
     ERR_FILE_EX, /**< File does not exist */
     ERR_ALLOC,   /**< Alloc error */
-    ERR_TYPE     /**< Wrong type */
+    ERR_TYPE,    /**< Wrong type */
+    ERR_CFG_NOF  /**< No config files found */
 };
 /*----------------------------------------------------------------------------*/
 /**
